@@ -121,6 +121,7 @@ class JHUData(CleaningBase):
         df.loc[df[self.COUNTRY] == "Diamond Princess", [
             self.COUNTRY, self.PROVINCE]] = ["Others", "Diamond Princess"]
         # Values
+        df = df.interpolate(limit_direction="both")
         df[self.CI] = df[self.C] - df[self.F] - df[self.R]
         df[self.VALUE_COLUMNS] = df[self.VALUE_COLUMNS].astype(np.int64)
         df = df.loc[:, [self.ISO3, *self.COLUMNS]].reset_index(drop=True)
@@ -178,21 +179,23 @@ class JHUData(CleaningBase):
             Records with Recovered > 0 will be selected.
         """
         # Subset with area and start/end date
-        df = super().subset(
+        subset_df = super().subset(
             country=country, province=province, start_date=start_date, end_date=end_date)
         # Select records where Recovered > 0
-        df = df.loc[df[self.R] > 0, :]
+        df = subset_df.loc[subset_df[self.R] > 0, :]
+        df = df.reset_index(drop=True)
         if df.empty:
+            series = subset_df[self.DATE]
+            start_date = start_date or series.min().strftime(self.DATE_FORMAT)
+            end_date = end_date or series.max().strftime(self.DATE_FORMAT)
             s1 = "Records with Recovered > 0 are not registered."
             s2 = f"(country={country}, province={province}, period={start_date}-{end_date})"
-            raise ValueError(
-                f"{s1} {s2}"
-            )
+            raise ValueError(f"{s1} {s2}")
         # Calculate Susceptible if population value was applied
         if population is None:
             return df
         population = self.ensure_natural_int(population, name="population")
-        df[self.S] = population - df[self.C]
+        df.loc[:, self.S] = population - df.loc[:, self.C]
         return df
 
     def to_sr(self, country, province=None,
